@@ -49,11 +49,11 @@ from firebolt.utils.exception import (
 from firebolt.utils.util import cached_property
 
 _NoneType = type(None)
-_col_types = (int, float, str, datetime, date, bool, list, Decimal, _NoneType)
+_col_types = (int, float, str, datetime, date, bool, list, Decimal, _NoneType, bytes)
 # duplicating this since 3.7 can't unpack Union
-ColType = Union[int, float, str, datetime, date, bool, list, Decimal, _NoneType]
+ColType = Union[int, float, str, datetime, date, bool, list, Decimal, _NoneType, bytes]
 RawColType = Union[int, float, str, bool, list, _NoneType]
-ParameterType = Union[int, float, str, datetime, date, bool, Decimal, Sequence]
+ParameterType = Union[int, float, str, datetime, date, bool, Decimal, Sequence, bytes]
 
 # These definitions are required by PEP-249
 Date = date
@@ -78,12 +78,13 @@ Timestamp = datetime
 TimestampFromTicks = datetime.fromtimestamp
 
 
-def Binary(value: str) -> str:
-    """Convert string to binary for Firebolt DB does nothing."""
-    return value
+def Binary(value: str) -> bytes:
+    """Encode a string into UTF-8."""
+    return value.encode("utf-8")
 
 
-STRING = BINARY = str
+STRING = str
+BINARY = bytes
 NUMBER = int
 DATETIME = datetime
 ROWID = int
@@ -105,11 +106,12 @@ Column = namedtuple(
 class ARRAY:
     """Class for holding `array` column type information in Firebolt DB."""
 
-    _prefix = "Array("
+    __name__ = "Array"
+    _prefix = "array("
 
-    def __init__(self, subtype: Union[type, ARRAY, DECIMAL, DATETIME64]):
+    def __init__(self, subtype: Union[type, ARRAY, DECIMAL]):
         assert (subtype in _col_types and subtype is not list) or isinstance(
-            subtype, (ARRAY, DECIMAL, DATETIME64)
+            subtype, (ARRAY, DECIMAL)
         ), f"Invalid array subtype: {str(subtype)}"
         self.subtype = subtype
 
@@ -125,6 +127,7 @@ class ARRAY:
 class DECIMAL:
     """Class for holding `decimal` value information in Firebolt DB."""
 
+    __name__ = "Decimal"
     _prefix = "Decimal("
 
     def __init__(self, precision: int, scale: int):
@@ -143,94 +146,59 @@ class DECIMAL:
         return other.precision == self.precision and other.scale == self.scale
 
 
-class DATETIME64:
-    """Class for holding `datetime64` value information in Firebolt DB."""
-
-    _prefix = "DateTime64("
-
-    def __init__(self, precision: int):
-        self.precision = precision
-
-    def __str__(self) -> str:
-        return f"DateTime64({self.precision})"
-
-    def __hash__(self) -> int:
-        return hash(str(self))
-
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, DATETIME64):
-            return NotImplemented
-        return other.precision == self.precision
-
-
-NULLABLE_PREFIX = "Nullable("
+NULLABLE_SUFFIX = "null"
 
 
 class _InternalType(Enum):
     """Enum of all internal Firebolt types, except for `array`."""
 
-    # INT, INTEGER
-    Int8 = "Int8"
-    UInt8 = "UInt8"
-    Int16 = "Int16"
-    UInt16 = "UInt16"
-    Int32 = "Int32"
-    UInt32 = "UInt32"
+    Int = "int"
+    Long = "long"
+    Float = "float"
+    Double = "double"
 
-    # BIGINT, LONG
-    Int64 = "Int64"
-    UInt64 = "UInt64"
+    Text = "text"
 
-    # FLOAT
-    Float32 = "Float32"
+    Date = "date"
+    DateExt = "date_ext"
+    PGDate = "pgdate"
 
-    # DOUBLE, DOUBLE PRECISION
-    Float64 = "Float64"
+    Timestamp = "timestamp"
+    TimestampExt = "timestamp_ext"
+    TimestampNtz = "timestampntz"
+    TimestampTz = "timestamptz"
 
-    # VARCHAR, TEXT, STRING
-    String = "String"
+    Boolean = "boolean"
 
-    # DATE
-    Date = "Date"
-    Date32 = "Date32"
-    PGDate = "PGDate"
+    Bytea = "bytea"
 
-    # DATETIME, TIMESTAMP
-    DateTime = "DateTime"
-    TimestampNtz = "TimestampNtz"
-    TimestampTz = "TimestampTz"
-
-    # Nullable(Nothing)
     Nothing = "Nothing"
 
     @cached_property
     def python_type(self) -> type:
         """Convert internal type to Python type."""
         types = {
-            _InternalType.Int8: int,
-            _InternalType.UInt8: int,
-            _InternalType.Int16: int,
-            _InternalType.UInt16: int,
-            _InternalType.Int32: int,
-            _InternalType.UInt32: int,
-            _InternalType.Int64: int,
-            _InternalType.UInt64: int,
-            _InternalType.Float32: float,
-            _InternalType.Float64: float,
-            _InternalType.String: str,
+            _InternalType.Int: int,
+            _InternalType.Long: int,
+            _InternalType.Float: float,
+            _InternalType.Double: float,
+            _InternalType.Text: str,
             _InternalType.Date: date,
-            _InternalType.Date32: date,
+            _InternalType.DateExt: date,
             _InternalType.PGDate: date,
-            _InternalType.DateTime: datetime,
+            _InternalType.Timestamp: datetime,
+            _InternalType.TimestampExt: datetime,
             _InternalType.TimestampNtz: datetime,
             _InternalType.TimestampTz: datetime,
+            _InternalType.Boolean: bool,
+            _InternalType.Bytea: bytes,
             # For simplicity, this could happen only during 'select null' query
             _InternalType.Nothing: str,
         }
         return types[self]
 
 
-def parse_type(raw_type: str) -> Union[type, ARRAY, DECIMAL, DATETIME64]:  # noqa: C901
+def parse_type(raw_type: str) -> Union[type, ARRAY, DECIMAL]:  # noqa: C901
     """Parse typename provided by query metadata into Python type."""
     if not isinstance(raw_type, str):
         raise DataError(f"Invalid typename {str(raw_type)}: str expected")
@@ -246,18 +214,9 @@ def parse_type(raw_type: str) -> Union[type, ARRAY, DECIMAL, DATETIME64]:  # noq
             pass
         else:
             return DECIMAL(precision, scale)
-    # Handle detetime64
-    if raw_type.startswith(DATETIME64._prefix) and raw_type.endswith(")"):
-        try:
-            precision = int(raw_type[len(DATETIME64._prefix) : -1])
-        except (ValueError, IndexError):
-            pass
-        else:
-            return DATETIME64(precision)
     # Handle nullable
-    if raw_type.startswith(NULLABLE_PREFIX) and raw_type.endswith(")"):
-        return parse_type(raw_type[len(NULLABLE_PREFIX) : -1])
-
+    if raw_type.endswith(NULLABLE_SUFFIX):
+        return parse_type(raw_type[: -len(NULLABLE_SUFFIX)].strip(" "))
     try:
         return _InternalType(raw_type).python_type
     except ValueError:
@@ -266,9 +225,21 @@ def parse_type(raw_type: str) -> Union[type, ARRAY, DECIMAL, DATETIME64]:  # noq
         return str
 
 
+BYTEA_PREFIX = "\\x"
+
+
+def _parse_bytea(str_value: str) -> bytes:
+    if (
+        len(str_value) < len(BYTEA_PREFIX)
+        or str_value[: len(BYTEA_PREFIX)] != BYTEA_PREFIX
+    ):
+        raise ValueError(f"Invalid bytea value format: {BYTEA_PREFIX} prefix expected")
+    return bytes.fromhex(str_value[len(BYTEA_PREFIX) :])
+
+
 def parse_value(
     value: RawColType,
-    ctype: Union[type, ARRAY, DECIMAL, DATETIME64],
+    ctype: Union[type, ARRAY, DECIMAL],
 ) -> ColType:
     """Provided raw value, and Python type; parses first into Python value."""
     if value is None:
@@ -281,10 +252,18 @@ def parse_value(
             raise DataError(f"Invalid date value {value}: str expected")
         assert isinstance(value, str)
         return parse_datetime(value).date()
-    if ctype is datetime or isinstance(ctype, DATETIME64):
+    if ctype is datetime:
         if not isinstance(value, str):
             raise DataError(f"Invalid datetime value {value}: str expected")
         return parse_datetime(value)
+    if ctype is bool:
+        if not isinstance(value, (bool, int)):
+            raise DataError(f"Invalid boolean value {value}: bool or int expected")
+        return bool(value)
+    if ctype is bytes:
+        if not isinstance(value, str):
+            raise DataError(f"Invalid bytea value {value}: str expected")
+        return _parse_bytea(value)
     if isinstance(ctype, DECIMAL):
         assert isinstance(value, (str, int))
         return Decimal(value)
@@ -304,7 +283,7 @@ escape_chars = {
 def format_value(value: ParameterType) -> str:
     """For Python value to be used in a SQL query."""
     if isinstance(value, bool):
-        return str(int(value))
+        return "true" if value else "false"
     if isinstance(value, (int, float, Decimal)):
         return str(value)
     elif isinstance(value, str):
@@ -315,6 +294,9 @@ def format_value(value: ParameterType) -> str:
         return f"'{value.strftime('%Y-%m-%d %H:%M:%S')}'"
     elif isinstance(value, date):
         return f"'{value.isoformat()}'"
+    elif isinstance(value, bytes):
+        # Encode each byte into hex
+        return "'" + "".join(f"\\x{b:02x}" for b in value) + "'"
     if value is None:
         return "NULL"
     elif isinstance(value, Sequence):
